package proxy.packet;

import java.io.IOException;

import proxy.network.Protocol;
import proxy.handler.HandshakeHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class H00PacketHandshake implements Packet<HandshakeHandler>
{
    private int protocolVersion;
    private String ip;
    private int port;
    private Protocol requestedState;

    public H00PacketHandshake()
    {
    }

    public H00PacketHandshake(int version, String ip, int port, Protocol requestedState)
    {
        this.protocolVersion = version;
        this.ip = ip;
        this.port = port;
        this.requestedState = requestedState;
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.protocolVersion = buf.readVarIntFromBuffer();
        this.ip = buf.readStringFromBuffer(255);
        this.port = buf.readUnsignedShort();
        this.requestedState = Protocol.getById(buf.readVarIntFromBuffer());
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeVarIntToBuffer(this.protocolVersion);
        buf.writeString(this.ip);
        buf.writeShort(this.port);
        buf.writeVarIntToBuffer(this.requestedState.getId());
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(HandshakeHandler handler)
    {
        handler.processHandshake(this);
    }

    public Protocol getRequestedState()
    {
        return this.requestedState;
    }

    public int getProtocolVersion()
    {
        return this.protocolVersion;
    }
}
