package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler.ProxyLoginHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;
import proxy.util.Formatter;

public class R00PacketDisconnect implements Packet<ProxyLoginHandler>
{
    private String reason;

    public R00PacketDisconnect()
    {
    }

    public R00PacketDisconnect(String reasonIn)
    {
        this.reason = Formatter.toJsonString(reasonIn);
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.reason = buf.readChatComponent();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeChatComponent(this.reason);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyLoginHandler handler)
    {
        handler.handleDisconnect(this);
    }

    public String getReason()
    {
        return Formatter.getStringOrJson(this.reason);
    }
}
