package proxy.packet;

import java.io.IOException;
import java.util.Arrays;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S26PacketMapChunkBulk implements Packet<ProxyHandler>
{
    private int[] xPositions;
    private int[] zPositions;
    private S21PacketChunkData.Extracted[] chunksData;
    private boolean isOverworld;

    public S26PacketMapChunkBulk()
    {
    }

    public S26PacketMapChunkBulk(int x, int y, int z)
    {
        this.xPositions = new int[1];
        this.zPositions = new int[1];
        this.chunksData = new S21PacketChunkData.Extracted[1];
        this.isOverworld = true;
        this.xPositions[0] = x >> 4;
        this.zPositions[0] = z >> 4;
        this.chunksData[0] = getExtractedData(x, y, z);
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.isOverworld = buf.readBoolean();
        int i = buf.readVarIntFromBuffer();
        this.xPositions = new int[i];
        this.zPositions = new int[i];
        this.chunksData = new S21PacketChunkData.Extracted[i];

        for (int j = 0; j < i; ++j)
        {
            this.xPositions[j] = buf.readInt();
            this.zPositions[j] = buf.readInt();
            this.chunksData[j] = new S21PacketChunkData.Extracted();
            this.chunksData[j].dataSize = buf.readShort() & 65535;
            this.chunksData[j].data = new byte[func_180737_a(Integer.bitCount(this.chunksData[j].dataSize), this.isOverworld, true)];
        }

        for (int k = 0; k < i; ++k)
        {
            buf.readBytes(this.chunksData[k].data);
        }
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeBoolean(this.isOverworld);
        buf.writeVarIntToBuffer(this.chunksData.length);

        for (int i = 0; i < this.xPositions.length; ++i)
        {
            buf.writeInt(this.xPositions[i]);
            buf.writeInt(this.zPositions[i]);
            buf.writeShort((short)(this.chunksData[i].dataSize & 65535));
        }

        for (int j = 0; j < this.xPositions.length; ++j)
        {
            buf.writeBytes(this.chunksData[j].data);
        }
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleMapChunkBulk(this);
    }

    protected static int func_180737_a(int p_180737_0_, boolean p_180737_1_, boolean p_180737_2_)
    {
        int i = p_180737_0_ * 2 * 16 * 16 * 16;
        int j = p_180737_0_ * 16 * 16 * 16 / 2;
        int k = p_180737_1_ ? p_180737_0_ * 16 * 16 * 16 / 2 : 0;
        int l = p_180737_2_ ? 256 : 0;
        return i + j + k + l;
    }

    public static S21PacketChunkData.Extracted getExtractedData(int x, int y, int z)
    {
        S21PacketChunkData.Extracted seg = new S21PacketChunkData.Extracted();
        seg.dataSize = 1 << (y >> 4);
        seg.data = new byte[func_180737_a(1, true, true)];
        int id1 = (x & 15) | (y & 15) << 8 | (z & 15) << 4;
        int id2 = (x & 15) | ((y + 2) & 15) << 8 | ((z + 1) & 15) << 4;
        int id3 = (x & 15) | ((y + 2) & 15) << 8 | ((z + 2) & 15) << 4;
        int j = 0;

        char[] achar = new char[4096];

        for (int n = 0; n < achar.length; n++)
        {
        	char c0 = (char)(n == id1 ? 2 << 4 : (n == id2 ? (68 << 4) | 2 : (n == id3 ? 166 << 4 : 0)));
            seg.data[j++] = (byte)(c0 & 255);
            seg.data[j++] = (byte)(c0 >> 8 & 255);
        }

        byte[] adata = new byte[2048];
        j = func_179757_a(adata, seg.data, j);
        Arrays.fill(adata, (byte)255);
        j = func_179757_a(adata, seg.data, j);
        adata = new byte[256];
        Arrays.fill(adata, (byte)1);
        func_179757_a(adata, seg.data, j);

        return seg;
    }

    private static int func_179757_a(byte[] p_179757_0_, byte[] p_179757_1_, int p_179757_2_)
    {
        System.arraycopy(p_179757_0_, 0, p_179757_1_, p_179757_2_, p_179757_0_.length);
        return p_179757_2_ + p_179757_0_.length;
    }
}
