package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S29PacketSoundEffect implements Packet<ProxyHandler>
{
    private String soundName;
    private int posX;
    private int posY = Integer.MAX_VALUE;
    private int posZ;
    private float soundVolume;
    private int soundPitch;

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.soundName = buf.readStringFromBuffer(256);
        this.posX = buf.readInt();
        this.posY = buf.readInt();
        this.posZ = buf.readInt();
        this.soundVolume = buf.readFloat();
        this.soundPitch = buf.readUnsignedByte();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeString(this.soundName);
        buf.writeInt(this.posX);
        buf.writeInt(this.posY);
        buf.writeInt(this.posZ);
        buf.writeFloat(this.soundVolume);
        buf.writeByte(this.soundPitch);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleSoundEffect(this);
    }
}
