package proxy.packet;

import java.io.IOException;
import java.util.Map;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;

public class S35PacketUpdateTileEntity implements Packet<ProxyHandler>
{
    private Vec3 blockPos;
    private int metadata;
    private Map<String, Object> nbt;

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.blockPos = buf.readVector();
        this.metadata = buf.readUnsignedByte();
        this.nbt = buf.readNBTTagCompoundFromBuffer();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeVector(this.blockPos);
        buf.writeByte((byte)this.metadata);
        buf.writeNBTTagCompoundToBuffer(this.nbt);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleUpdateTileEntity(this);
    }
}
