package proxy.packet;

import java.io.IOException;

import proxy.handler.ProxyHandler;
import proxy.network.Packet;
import proxy.network.PacketBuffer;
import proxy.util.Formatter;

public class S40PacketDisconnect implements Packet<ProxyHandler>
{
    private String reason;

    public S40PacketDisconnect()
    {
    }

    public S40PacketDisconnect(String reasonIn)
    {
        this.reason = Formatter.toJsonString(reasonIn);
    }

    /**
     * Reads the raw packet data from the data stream.
     */
    public void readPacketData(PacketBuffer buf) throws IOException
    {
        this.reason = buf.readChatComponent();
    }

    /**
     * Writes the raw packet data to the data stream.
     */
    public void writePacketData(PacketBuffer buf) throws IOException
    {
        buf.writeChatComponent(this.reason);
    }

    /**
     * Passes this Packet on to the NetHandler for processing.
     */
    public void processPacket(ProxyHandler handler)
    {
        handler.handleDisconnect(this);
    }

    public String getReason()
    {
        return Formatter.getStringOrJson(this.reason);
    }
}
